var utils = {};

var types = {
	isElement : function(node) {
		return node.nodeName && (node.nodeType === 1 || node.nodeType === 9);
	},
	isString : function(value) {
		return Object.prototype.toString.call(value) === '[object String]';
	},
	isArray : function(obj) {
		return Object.prototype.toString.call(obj) === '[object Array]';
	},
	isObject : function(obj) {
		return obj !== null && Object.prototype.toString.call(obj) === '[object Object]';
	},
	isFunction : function(obj) {
		return Object.prototype.toString.call(obj) === '[object Function]';
	}
};

var classes = {
	get : function(element) {
		return element.classList ? element.classList : element.className.split(/\s+/);
	},
	has : function(element, name) {
		return element.classList ? element.classList.contains(name) : !! ~utils.index(classes.get(element), name);
	},
	add : function(element, name) {
		name = name.trim();
		if (element.classList) {
			return element.classList.add(name);
		}
		classes = classes.get(element);
		var index = utils.index(classes, name);
		if (!~index) classes.push(name);
		element.className = classes.join(' ');
		return element;
	},

	remove : function(element, name) {
		name = name.trim();
		if (element.classList) {
			return element.classList.remove(name);
		}
		classes = classes.get(element);
		var index = index(classes, name);
		if (~index) classes.splice(index, 1);
		element.className = classes.join(' ');
		return element;
	},

	toggleClass : function(element, name) {
		name = name.trim();
		if (element.classList) {
			return element.classList.toggle(name);
		}
		return classes.has(element, name) ? classes.remove(element, name) : classes.add(element, name);
	},

};

utils.types = types;

utils.index = function(list, item) {
	return Array.prototype.indexOf.call(list, item);
};

utils.hasProp = function(obj, prop) {
	return obj !== null && Object.prototype.hasOwnProperty.call(obj, prop);
};

utils.add = function(element) {
	var args = Array.prototype.slice.call(arguments, 1);

	for (var i = 0, l = args.length; i < l; i++) {
		var arg = args[i];

		if (types.isString(arg)) {
			classes.add(element, arg);
		} else

		if (types.isArray(arg)) {
			for (var a = 0, b = arg.length; a < b; a++) {
				classes.add(element, arg[a]);
			}
		} else

		if (types.isObject(arg)) {
			for (var property in arg) {
				if (property !== null && utils.hasProp(arg, property)) {
					element.setAttribute(property, arg[property]);
				}
			}
		}
	}
};

module.exports = utils;